@@ -35,7 +35,7 @@
 
 (use-modules (nyacc lang sx-util))
 (use-modules (nyacc lang util))
-(use-modules ((srfi srfi-1) #:select (fold-right)))
+(use-modules ((srfi srfi-1) #:select (fold-right append-reverse)))
 (use-modules ((srfi srfi-9) #:select (define-record-type)))
 (use-modules (ice-9 pretty-print))	; for debugging
 (define pp pretty-print)
@@ -129,18 +129,6 @@
 
 (define *info* (make-fluid))
 	  
-;; @deffn {Procedure} typename? name
-;; Called by lexer to determine if symbol is a typename.
-;; Check current sibling for each generation.
-;; @end deffn
-(define (typename? name)
-  (let ((cpi (fluid-ref *info*)))
-    (if (member name (cpi-ctl cpi)) #t
-        (let iter ((ptl (cpi-ptl cpi)))
-	  (if (null? ptl) #f
-	      (if (member name (car ptl)) #t
-		  (iter (cdr ptl))))))))
-
 (define cpi-inc-blev!
   (case-lambda
     ((info) (set-cpi-blev! info (1+ (cpi-blev info))))
@@ -154,24 +142,21 @@
     ((info) (zero? (cpi-blev info)))
     (() (cpi-top-blev? (fluid-ref *info*)))))
 
-;; @deffn {Procedure} add-typename name
-;; Helper for @code{save-typenames}.
-;; @end deffn
-(define (add-typename name)
-  (let ((cpi (fluid-ref *info*)))
-    (set-cpi-ctl! cpi (cons name (cpi-ctl cpi)))))
+(define cpi-push
+  (case-lambda
+    ((info) 
+     (set-cpi-ptl! info (cons (cpi-ctl info) (cpi-ptl info)))
+     (set-cpi-ctl! info '())
+     #t)
+    (() (cpi-push (fluid-ref *info*)))))
 
-(define (cpi-push)
-  (let ((cpi (fluid-ref *info*)))
-    (set-cpi-ptl! cpi (cons (cpi-ctl cpi) (cpi-ptl cpi)))
-    (set-cpi-ctl! cpi '())
-    #t))
-
-(define (cpi-pop)
-  (let ((cpi (fluid-ref *info*)))
-    (set-cpi-ctl! cpi (car (cpi-ptl cpi)))
-    (set-cpi-ptl! cpi (cdr (cpi-ptl cpi)))
-    #t))
+(define cpi-pop
+  (case-lambda
+    ((info)
+     (set-cpi-ctl! info (car (cpi-ptl info)))
+     (set-cpi-ptl! info (cdr (cpi-ptl info)))
+     #t)
+    (() (cpi-pop (fluid-ref *info*)))))
 
 (define (cpi-push-x)	;; on #if
   (let ((cpi (fluid-ref *info*)))
@@ -186,6 +171,25 @@
     (set-cpi-ctl! cpi (append (cpi-ctl cpi) (car (cpi-ptl cpi))))
     (set-cpi-ptl! cpi (cdr (cpi-ptl cpi)))))
 
+;; @deffn {Procedure} typename? name
+;; Called by lexer to determine if symbol is a typename.
+;; Check current sibling for each generation.
+;; @end deffn
+(define (typename? name)
+  (let ((cpi (fluid-ref *info*)))
+    (if (member name (cpi-ctl cpi)) #t
+        (let iter ((ptl (cpi-ptl cpi)))
+	  (if (null? ptl) #f
+	      (if (member name (car ptl)) #t
+		  (iter (cdr ptl))))))))
+
+;; @deffn {Procedure} add-typename name
+;; Helper for @code{save-typenames}.
+;; @end deffn
+(define (add-typename name)
+  (let ((cpi (fluid-ref *info*)))
+    (set-cpi-ctl! cpi (cons name (cpi-ctl cpi)))))
+
 ;; @deffn {Procedure} find-new-typenames decl
 ;; Helper for @code{save-typenames}.
 ;; Given declaration return a list of new typenames (via @code{typedef}).
@@ -225,13 +229,13 @@
 
 ;; (string "abc" "def") -> (string "abcdef")
 (define (join-string-literal str-lit)
-  (sx-join 'string (sx-attr str-lit) (string-join (sx-tail str-lit) "")))
+  (sx-list 'string (sx-attr str-lit) (string-join (sx-tail str-lit) "")))
 
 ;; In the case that declaration-specifiers only returns a list of
 ;; attribute-specifiers then this has to be an empty-statemnet with
 ;; attributes.  See:
 ;;   https://gcc.gnu.org/onlinedocs/gcc-8.2.0/gcc/Statement-Attributes.html
-(define (only-attr-specs? specs)
+(define (XXX-only-attr-specs? specs)
   (let loop ((specs specs))
     (cond
      ((null? specs) #t)
@@ -254,9 +258,47 @@
       ((attr-expr-list . ,expr-list)
        (string-join (map spec->str expr-list) ","))
       ((fixed ,val) val)
+      ((string ,val) (string-append "\"" val "\""))
       (,_ (simple-format #t "c99/body: missed ~S\n" spec) "MISSED")))
   `(attributes ,(string-join (map spec->str (sx-tail attr-spec)) ";")))
 
+;; move @code{(attributes ...)} from under @code{decl-spec-list} to
+;; under @code{@}
+;; @example
+;; (decl (decl-spec-list
+;;         (attributes "packed" "aligned")
+;;         (attributes "alignof(8)"))
+;;         (type-spec (fixed-type "int")))
+;;       (declr-init-list ...))
+;;  =>
+;; (decl (@ (attributes "packed;aligned;alignof(8)"))
+;;       (decl-spec-list
+;;         (type-spec (fixed-type "int")))
+;;       (declr-init-list ...))
+;; @end example
+(define (move-attributes decl)
+  (define (comb-attr attl attr)
+    (cons `(attributes
+	    ,(string-join
+	      (let loop ((rz '()) (al attl))
+		(if (null? al) rz (loop (cons (cadar al) rz) (cdr al))))
+	      ";")) attr))
+  (define (make-specl spl)
+    (cons 'decl-spec-list (reverse spl)))
+  (let ((tag (sx-tag decl))
+	(attr (sx-attr decl))
+	(spec-l (sx-ref decl 1))
+	(declr-l (sx-ref decl 2)))
+    (let loop ((attl '()) (spl1 '()) (spl0 (sx-tail spec-l)))
+      (cond
+       ((null? spl0)
+	(if (null? attl) decl
+	    (sx-list tag (comb-attr attl attr) (make-specl spl1) declr-l)))
+       ((eq? 'attributes (sx-tag (car spl0)))
+	(loop (cons (attr-spec->attr (car spl0)) attl) spl1 (cdr spl0)))
+       (else
+	(loop attl (cons (car spl0) spl1) (cdr spl0)))))))
+
 ;; ------------------------------------------------------------------------
 
 (define (c99-err . args)
@@ -622,17 +664,17 @@
 		      ;;          (assq-ref keytab symb))
 		      => (lambda (t) (cons t name)))
 		     ((typename? name)
-		      (cons (assq-ref symtab 'typename) name))
+		      (cons t-typename name))
 		     (else
-		      (cons (assq-ref symtab '$ident) name))))))
+		      (cons t-ident name))))))
 	       ((read-c-num ch) => assc-$)
 	       ((read-c-string ch) => assc-$)
 	       ((read-c-comm ch #f #:skip-prefix #t) => assc-$)
 	       ;; Keep track of brace level and scope for typedefs.
-	       ((and (char=? ch #\{) (cpi-push)
+	       ((and (char=? ch #\{)
 		     (eqv? 'keep (car ppxs)) (cpi-inc-blev! info)
 		     #f) #f)
-	       ((and (char=? ch #\}) (cpi-pop)
+	       ((and (char=? ch #\})
 		     (eqv? 'keep (car ppxs)) (cpi-dec-blev! info)
 		     #f) #f)
 	       ((read-chseq ch) => identity)
