@@ -85,7 +85,7 @@
   #:use-module (ice-9 rdelim)
   #:use-module (ice-9 regex)
   #:re-export (*nyacc-version*)
-  #:version (0 86 6)
+  #:version (0 86 7)
   )
 
 (define (fhoo) #t)			; debugging
@@ -663,7 +663,7 @@
 	 (ty*-desc (and typename (strings->symbol typename "*-desc")))
 	 (ag-desc (and aggrname (strings->symbol aggrname "-desc")))
 	 (ag*-desc (and aggrname (strings->symbol aggrname "*-desc")))
-	 (packed? (and attr (assoc-ref attr "__packed__")))
+	 (packed? (and attr (or (assoc-ref attr "__packed__"))))
 	 (bs-spec (if packed?
 		      (list bs-aggr-t #t `(list ,@sflds))
 		      (list bs-aggr-t `(list ,@sflds))))
